@@ -3,6 +3,7 @@
 
 from zope.testing import doctest
 import manuel
+import manuel.codeblock
 import manuel.doctest
 import manuel.footnote
 import manuel.testing
@@ -65,15 +66,6 @@ class Result(object):
                      self.test.expression, self.error))
 
 
-class Document(manuel.Document):
-
-    def evaluate_with(self, m, globs):
-        globs = manuel.GlobWrapper(globs)
-        for region in self:
-            for evaluater in manuel.sort_handlers(m.evaluaters):
-                evaluater(region, self, globs)
-
-
 class Manuel(manuel.Manuel):
 
     def __init__(self, Test, Result):
@@ -82,7 +74,6 @@ class Manuel(manuel.Manuel):
         super(Manuel, self).__init__(parsers=[self.parse],
                                      evaluaters=[self.evaluate],
                                      formatters=[self.format])
-        self.extend(manuel.footnote.Manuel())
 
     def parse(self, document):
         for region in document.find_regions(self.Test.finder):
@@ -108,14 +99,18 @@ def DocFileSuite(path, module_relative=True, package=None,
                  optionflags=0, checker=None, encoding=None,
                  manuel_object=None):
     m = manuel.doctest.Manuel(optionflags=optionflags, checker=checker)
-    m.extend(manuel_object or Manuel(Test, Result))
+    m.extend(manuel.footnote.Manuel())
+    m.extend(manuel.codeblock.Manuel())
+    m.extend(Manuel(Test, Result))
+    if manuel_object:
+        m.extend(manuel_object)
 
     if module_relative:
         calling_module = doctest._normalize_module(package)
         path = doctest._module_relative_path(calling_module, path)
 
-    document = Document(open(path).read().decode(encoding or 'ascii'),
-                        location=path)
+    document = manuel.Document(open(path).read().decode(encoding or 'ascii'),
+                               location=path)
 
     return unittest.TestSuite([
         manuel.testing.TestCase(m, document,
